@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,10 +27,15 @@ namespace NoteShared {
 class NOTESHARED_EXPORT NoteUtils
 {
 public:
+    struct NoteText {
+        QString noteTitle;
+        QString noteText;
+    };
     NoteUtils();
-    bool sendToMail(QWidget *parent, const QString &title, const QString &message);
+    Q_REQUIRED_RESULT bool sendToMail(QWidget *parent, const QString &title, const QString &message);
     void sendToNetwork(QWidget *parent, const QString &title, const QString &message);
-    QString createToolTip(const Akonadi::Item &item);
+    Q_REQUIRED_RESULT QString createToolTip(const Akonadi::Item &item);
+    Q_REQUIRED_RESULT NoteText extractNoteText(QString noteText, const QString &titleAddon);
 };
 }
 
